@@ -16,11 +16,14 @@
 #
 
 from pyspark.ml.param import *
-from pyspark.ml.util import JavaMLWritable, JavaMLReadable
+from pyspark.ml.util import JavaMLWritable
 from pyspark.ml.wrapper import JavaModel
+from ai.h2o.sparkling.ml.util.H2OJavaMLReadable import H2OJavaMLReadable
+
+import warnings
 
 
-class H2OMOJOModelBase(JavaModel, JavaMLWritable, JavaMLReadable):
+class H2OMOJOModelBase(JavaModel, JavaMLWritable, H2OJavaMLReadable):
 
     # Overriding the method to avoid changes on the companion Java object
     def _transfer_params_to_java(self):
@@ -36,7 +39,9 @@ class H2OMOJOModelBase(JavaModel, JavaMLWritable, JavaMLReadable):
         return self._java_obj.getDetailedPredictionCol()
 
     def getWithDetailedPredictionCol(self):
-        return self._java_obj.getWithDetailedPredictionCol()
+        warnings.warn("The method will be removed without a replacement in the version 3.34."
+                      "Detailed prediction columns is always enabled.", DeprecationWarning)
+        return True
 
     def getFeaturesCols(self):
         return list(self._java_obj.getFeaturesCols())
@@ -52,3 +57,6 @@ class H2OMOJOModelBase(JavaModel, JavaMLWritable, JavaMLReadable):
 
     def getWithContributions(self):
         return self._java_obj.getWithContributions()
+
+    def getWithLeafNodeAssignments(self):
+        return self._java_obj.getWithLeafNodeAssignments()
